==> duiba-live-supplier-center-api-0.0.1-20220108.022314-19-sources.jar: cn/com/duiba/supplier/center/api/dto/DuibaLiveSupplierUpdateDto.java <==
package cn.com.duiba.supplier.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @date:2022/1/7 11:40
 * @author:zhaozhanghai
 * @Description:
 */
public class DuibaLiveSupplierUpdateDto implements Serializable {


    private static final long serialVersionUID = 73861846586514878L;
    /**
     * 主键id
     */
    private Long id;

    /**
     * 供应商简称
     */
    private String supplierShortName;

    /**
     * 联系人
     */
    private String contactName;

    /**
     * 联系电话
     */
    private String contactPhone;


    /**
     * 登录名
     */
    private String loginAccount;

    /**
     * 登陆密码
     */
    private String loginPassword;



    /**
     * 类目资质图片url  http://1.jpg,http://2.jpg
     */
    private String categoryQualifications;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSupplierShortName() {
        return supplierShortName;
    }

    public void setSupplierShortName(String supplierShortName) {
        this.supplierShortName = supplierShortName;
    }

    public String getContactName() {
        return contactName;
    }

    public void setContactName(String contactName) {
        this.contactName = contactName;
    }

    public String getContactPhone() {
        return contactPhone;
    }

    public void setContactPhone(String contactPhone) {
        this.contactPhone = contactPhone;
    }

    public String getLoginAccount() {
        return loginAccount;
    }

    public void setLoginAccount(String loginAccount) {
        this.loginAccount = loginAccount;
    }

    public String getLoginPassword() {
        return loginPassword;
    }

    public void setLoginPassword(String loginPassword) {
        this.loginPassword = loginPassword;
    }

    public String getCategoryQualifications() {
        return categoryQualifications;
    }

    public void setCategoryQualifications(String categoryQualifications) {
        this.categoryQualifications = categoryQualifications;
    }
}

==> duiba-live-supplier-center-api-0.0.1-20220112.061235-23-sources.jar: cn/com/duiba/supplier/center/api/dto/DuibaLiveSupplierUpdateDto.java <==
package cn.com.duiba.supplier.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @date:2022/1/7 11:40
 * @author:zhaozhanghai
 * @Description:
 */
public class DuibaLiveSupplierUpdateDto implements Serializable {


    private static final long serialVersionUID = 73861846586514878L;
    /**
     * 主键id
     */
    private Long id;

    /**
     * 供应商简称
     */
    private String supplierShortName;

    /**
     * 联系人
     */
    private String contactName;

    /**
     * 联系电话
     */
    private String contactPhone;


    /**
     * 登录名
     */
    private String loginAccount;

    /**
     * 登陆密码
     */
    private String loginPassword;

    /**
     * 经营类目goodsType 1-实物 2-卡券 3-虚拟商品  [{type:1,itemClassifyId:[{id:1,name:食品酒水}]},{type:2}]
     */
    private String businessCategory;


    /**
     * 类目资质图片url  http://1.jpg,http://2.jpg
     */
    private String categoryQualifications;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSupplierShortName() {
        return supplierShortName;
    }

    public void setSupplierShortName(String supplierShortName) {
        this.supplierShortName = supplierShortName;
    }

    public String getContactName() {
        return contactName;
    }

    public void setContactName(String contactName) {
        this.contactName = contactName;
    }

    public String getContactPhone() {
        return contactPhone;
    }

    public void setContactPhone(String contactPhone) {
        this.contactPhone = contactPhone;
    }

    public String getLoginAccount() {
        return loginAccount;
    }

    public void setLoginAccount(String loginAccount) {
        this.loginAccount = loginAccount;
    }

    public String getLoginPassword() {
        return loginPassword;
    }

    public void setLoginPassword(String loginPassword) {
        this.loginPassword = loginPassword;
    }

    public String getCategoryQualifications() {
        return categoryQualifications;
    }

    public void setCategoryQualifications(String categoryQualifications) {
        this.categoryQualifications = categoryQualifications;
    }

    public String getBusinessCategory() {
        return businessCategory;
    }

    public void setBusinessCategory(String businessCategory) {
        this.businessCategory = businessCategory;
    }
}
